<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>测试报告</title>
    <!--    页面样式-->
    <style type="text/css">
        .main {
            height: 300px;
        }

        /*汇总信息样式*/
        .summary {
            width: 90%;
            position: absolute;
            margin-left: 5%;
        }

        .title {
            width: auto;
            height: 60px;
            text-align: center;
            font: bolder 38px/60px "Microsoft YaHei UI";
            color: #02992c;
            margin-bottom: 50px;
        }

        .text-left {
            text-align: left;
            font: bolder 20px/30px "Microsoft YaHei UI";
            color: #02992c;
            margin-bottom: 20px;
        }

        td, th {
            border: solid 1px rgba(133, 137, 140, 0.76);
            height: 50px;
            width: 200px;
        }

        td {
            color: #02992c;
            padding-left: 5%;
        }
        th {
            color: #00a10a;

        }
    </style>

</head>
<body>
<div class="main">
    <!--汇总信息-->
    <div class="summary">
        <div class="text-left">【{{ title }}】用例执行汇总信息如下：</div>
        <table width=60% border="1" cellpadding="0" cellspacing="0" bordercolor="#FF0000"
               style="border-collapse:collapse;">
            <tr>
                <th>测试人员</th>
                <td>{{ tester }}</td>
                <th>成功用例</th>
                <td><span>{{ success }}</span></td>
            </tr>
            <tr>
                <th>开始时间</th>
                <td><span>{{ begin_time }}</span></td>
                <th style="color: #cc8b0c">失败用例</th>
                <td style="color: #cc8b0c">{{ fail }}</td>
            </tr>
            <tr>
                <th>执行时间</th>
                <td><span>{{ runtime }}</span></td>
                <th style="color: #cc0109">错误用例</th>
                <td><span style="color: #cc0109">{{ error }}</span></td>
            </tr>
            <tr>
                <th>用例总数</th>
                <td><span>{{ all }}</span></td>
                <th style="color: #575a5c">跳过用例</th>
                <td><span style="color: #575a5c">{{ skip }}</span></td>
            </tr>
        </table>
    </div>

</div>


</body>
</html>